@@ -1,7 +1,7 @@
 package PICA::Data;
 use v5.14.1;
 
-our $VERSION = '2.09';
+our $VERSION = '2.10';
 
 use Exporter 'import';
 our @EXPORT_OK
@@ -396,6 +396,7 @@ use PICA::Patch;
 use PICA::Parser::XML;
 use PICA::Parser::Plus;
 use PICA::Parser::Plain;
+use PICA::Parser::Import;
 use PICA::Parser::Binary;
 use PICA::Parser::PPXML;
 use PICA::Parser::PIXML;
@@ -655,6 +656,10 @@ L<PICA::Parser::Plain> for type C<plain> or C<picaplain> (human-readable PICA+)
 
 L<PICA::Parser::Plus> for type C<plus> or C<picaplus> (normalized PICA+)
 
+=item 
+
+L<PICA::Parser::Import> for type C<import> (PICA Import format)
+
 =item
 
 L<PICA::Parser::JSON> for type C<json> (PICA JSON)
